OC.L10N.register(
    "dav",
    {
    "Calendar" : "Agenda",
    "To-dos" : "Pense-bêtes",
    "Personal" : "Personnel",
    "{actor} created calendar {calendar}" : "{actor} a créé l'agenda {calendar}",
    "You created calendar {calendar}" : "Vous avez créé l'agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} a supprimé l'agenda {calendar}",
    "You deleted calendar {calendar}" : "Vous avez supprimé l'agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} a mis à jour l'agenda {calendar}",
    "You updated calendar {calendar}" : "Vous avez mis à jour l'agenda {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} a restauré l'agenda {calendar}",
    "You restored calendar {calendar}" : "Vous avez restauré l'agenda {calendar}",
    "You shared calendar {calendar} as public link" : "Vous avez partagé l'agenda {calendar} avec un lien public ",
    "You removed public link for calendar {calendar}" : "Vous avez supprimé le lien public pour l'agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} a partagé l'agenda {calendar} avec vous",
    "You shared calendar {calendar} with {user}" : "Vous avez partagé l'agenda {calendar} avec {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} a partagé l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} a cessé de partager l'agenda {calendar} avec vous",
    "You unshared calendar {calendar} from {user}" : "Vous avez cessé de partager l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} a cessé de partager l'agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} a cessé de partager l'agenda {calendar} avec lui-même",
    "You shared calendar {calendar} with group {group}" : "Vous avez partagé l'agenda {calendar} avec le groupe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} a partagé l'agenda {calendar} avec le groupe {group}",
    "You unshared calendar {calendar} from group {group}" : "Vous avez cessé de partager l'agenda {calendar} avec le groupe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} a cessé de partager l'agenda {calendar} avec le groupe {group}",
    "Untitled event" : "Événement sans titre",
    "{actor} created event {event} in calendar {calendar}" : "{actor} a créé l'évènement {event} dans l'agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Vous avez créé l'évènement {event} dans l'agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} a supprimé l'évènement {event} de l'agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vous avez supprimé l'évènement {event} de l'agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} a mis à jour l'évènement {event} dans l'agenda {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vous avez mis à jour l'évènement {event} dans l'agenda {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} a déplacé l'événement {event} du calendrier {sourceCalendar} au calendrier {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Vous avez déplacé l'événement {event} du calendrier {sourceCalendar} au calendrier {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} a restauré l'événement {event} dans l'agenda {calendar}",
    "You restored event {event} of calendar {calendar}" : "Vous avez restauré l'événement {event} dans l'agenda {calendar}",
    "Busy" : "Occupé",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} a créé la tâche {todo} dans la liste {calendar}",
    "You created to-do {todo} in list {calendar}" : "Vous avez créé un pense-bête {todo} dans la liste {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} a supprimé un pense-bête {todo} de la liste {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Vous avez supprimé le pense-bête {todo} de la liste {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} a mis à jour le pense-bête {todo} dans la liste {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Vous avez mis à jour le pense-bête {todo} dans la liste {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} a résolu le pense-bête {todo} dans la liste {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Vous avez résolu le pense-bête {todo} dans la liste {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} a réouvert le pense-bête {todo} dans la liste {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Vous avez réouvert le pense-bête {todo} dans la liste {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} a déplacé le pense-bête {todo} de la liste {sourceCalendar} à la liste {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Vous avez déplacé le pense-bête {todo} de la liste {sourceCalendar} à la liste {targetCalendar}",
    "Calendar, contacts and tasks" : "Agenda, contacts et tâches",
    "A <strong>calendar</strong> was modified" : "Un <strong>agenda</strong> a été modifié",
    "A calendar <strong>event</strong> was modified" : "Un <strong>événement</strong> de l'agenda a été modifié",
    "A calendar <strong>to-do</strong> was modified" : "Un calendrier <strong>de tâches</strong> a été modifié",
    "Contact birthdays" : "Anniversaires des contacts",
    "Death of %s" : "Mort de %s",
    "Untitled calendar" : "Calendrier sans titre",
    "Calendar:" : "Agenda:",
    "Date:" : "Date:",
    "Where:" : "Où :",
    "Description:" : "Description :",
    "_%n year_::_%n years_" : ["%n an","%n ans","%n ans"],
    "_%n month_::_%n months_" : ["%n mois","%n mois","%n mois"],
    "_%n day_::_%n days_" : ["%n jour","%n jours","%n jours"],
    "_%n hour_::_%n hours_" : ["%n heure","%n heures","%n heures"],
    "_%n minute_::_%n minutes_" : ["%n minute","%n minutes","%n minutes"],
    "%s (in %s)" : "%s (dans %s)",
    "%s (%s ago)" : "%s (il y a %s)",
    "Calendar: %s" : "Agenda: %s",
    "Date: %s" : "Date: %s",
    "Description: %s" : "Description: %s",
    "Where: %s" : "Où : %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Cancelled: %1$s" : "Annulé : %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" a été annulé(e)",
    "Re: %1$s" : "Re : %1$s",
    "%1$s has accepted your invitation" : "%1$s a accepté votre invitation",
    "%1$s has tentatively accepted your invitation" : "%1$s a provisoirement accepté votre invitation",
    "%1$s has declined your invitation" : "%1$s a décliné votre invitation",
    "%1$s has responded to your invitation" : "%1$s a répondu à votre invitation",
    "Invitation updated: %1$s" : "Invitation mise à jour : %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s a mis à jour l'évènement %2$s",
    "Invitation: %1$s" : "Invitation : %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s souhaite vous inviter à \"%2$s\"",
    "Organizer:" : "Organisateur :",
    "Attendees:" : "Participants :",
    "Title:" : "Titre :",
    "Time:" : "Heure :",
    "Location:" : "Localisation :",
    "Link:" : "Lien :",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "More options …" : "Plus d'options…",
    "More options at %s" : "Plus d'options à %s",
    "Contacts" : "Contacts",
    "{actor} created address book {addressbook}" : "{actor} a créé le carnet d'adresses {addressbook}",
    "You created address book {addressbook}" : "Vous avez créé le carnet d'adresses {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} a supprimé le carnet d'adresses {addressbook}",
    "You deleted address book {addressbook}" : "Vous avez supprimé le carnet d'adresses {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} a mis à jour le carnet d'adresses {addressbook}",
    "You updated address book {addressbook}" : "Vous avez mis à jour le carnet d'adresses {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} a partagé le carnet d'adresses {addressbook} avec vous",
    "You shared address book {addressbook} with {user}" : "Vous avez partagé le carnet d'adresses {addressbook} avec {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} a partagé le carnet d'adresses {addressbook} avec {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} a cessé de partager le carnet d'adresses {addressbook} vous appartenant",
    "You unshared address book {addressbook} from {user}" : "Vous avez cessé de partager le carnet d'adresses {addressbook} appartenant à {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} a cessé de partager le carnet d'adresses {addressbook} appartenant à {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} a cessé de partager le carnet d'adresses {addressbook} lui appartenant",
    "You shared address book {addressbook} with group {group}" : "Vous avez partagé le carnet d'adresses {addressbook} avec le groupe {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} a partagé le carnet d'adresses {addressbook} avec le groupe {group}",
    "You unshared address book {addressbook} from group {group}" : "Vous avez cessé de partager le carnet d'adresses {addressbook} appartenant au groupe {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} a cessé de partager le carnet d'adresses {addressbook} appartenant au groupe {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} a créé le contact {card} dans le carnet d'adresses {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Vous avez créé le contact {card} dans le carnet d'adresses {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} a supprimé le contact {card} dans le carnet d'adresses {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Vous avez supprimé le contact {card} dans le carnet d'adresses {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} a mis à jour le contact {card} dans le carnet d'adresses {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Vous avez mis à jour le contact {card} dans le carnet d'adresses {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Un <strong>contact</strong> ou <strong>carnet d'adresses</strong> a été modifié",
    "Accounts" : "Comptes",
    "System address book which holds all accounts" : "Annuaire système qui regroupe tous les comptes",
    "File is not updatable: %1$s" : "Ce fichier ne peut pas être mis à jour : %1$s",
    "Could not write to final file, canceled by hook" : "Impossible d'écrire dans le fichier final, annulé par le hook",
    "Could not write file contents" : "Impossible d'écrire le contenu du fichier",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets","%n octets"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Erreur en copiant le fichier à destination (copié : %1$s, taille du fichier attendue : %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Taille du fichier attendue : %1$s mais taille du fichier lue (depuis le client Nextcloud) et écrit (dans le stockage Nextcloud) : %2$s. Cela peut être un problème de réseau au niveau du client ou un problème de stockage au niveau du serveur.",
    "Could not rename part file to final file, canceled by hook" : "Impossible de renommer le fichier partiel en fichier final, annulé par le hook",
    "Could not rename part file to final file" : "Impossible de renommer le fichier partiel en fichier définitif.",
    "Failed to check file size: %1$s" : "Échec à la vérification de la taille du fichier : %1$s",
    "Could not open file" : "Impossible d'ouvrir le fichier",
    "Encryption not ready: %1$s" : "Encryption pas prête : %1$s",
    "Failed to open file: %1$s" : "Échec à l'ouverture du fichier : %1$s",
    "Failed to unlink: %1$s" : "Échec à la suppression :%1$s",
    "Invalid chunk name" : "Nom de morceau invalide",
    "Could not rename part file assembled from chunks" : "Impossible de renommer le fichier partiel à partir des morceaux",
    "Failed to write file contents: %1$s" : "Échec à l'écriture du contenu du fichier : %1$s",
    "File not found: %1$s" : "Fichier non trouvé : %1$s",
    "System is in maintenance mode." : "Le système est en mode maintenance.",
    "Upgrade needed" : "Mise à jour requise",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Votre %s a besoin d'être configuré pour utiliser le HTTPS dans le but d'utiliser CalDAV et CardDAV avec iOS/macOS.",
    "Configures a CalDAV account" : "Configure un compte CalDAV",
    "Configures a CardDAV account" : "Configure un compte CardDAV",
    "Events" : "Évènements",
    "Tasks" : "Tâches",
    "Untitled task" : "Tâche sans titre",
    "Completed on %s" : "Terminé le %s",
    "Due on %s by %s" : "Echéance le %s pour %s",
    "Due on %s" : "Echéance le %s",
    "Migrated calendar (%1$s)" : "Agenda migré (%1$s)",
    "Calendars including events, details and attendees" : "Calendriers incluant des événements, détails et participants",
    "Contacts and groups" : "Contacts et groupes",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Point d'accès WebDAV",
    "Availability" : "Disponibilité",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Si vous configurez vos heures de travail, les autres utilisateurs verront si vous êtes disponible quand ils planifient une réunion.",
    "Time zone:" : "Fuseau horaire :",
    "to" : "à",
    "Delete slot" : "Supprimer le créneau",
    "No working hours set" : "Heures de travail non définies",
    "Add slot" : "Ajouter un créneau",
    "Monday" : "Lundi",
    "Tuesday" : "Mardi",
    "Wednesday" : "Mercredi",
    "Thursday" : "Jeudi",
    "Friday" : "Vendredi",
    "Saturday" : "Samedi",
    "Sunday" : "Dimanche",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Définir automatiquement le statut \"Ne pas déranger\" en dehors des heures de disponibilité pour désactiver toutes les notifications.",
    "Save" : "Enregistrer",
    "Failed to load availability" : "Impossible de charger la disponibilité",
    "Saved availability" : "Disponibilité sauvegardée",
    "Failed to save availability" : "Impossible de sauvegarder la disponibilité",
    "Calendar server" : "Serveur de calendrier",
    "Send invitations to attendees" : "Envoyer des invitations aux participants",
    "Automatically generate a birthday calendar" : "Générer automatiquement un agenda d'anniversaire",
    "Birthday calendars will be generated by a background job." : "Les agendas d'anniversaire seront générés par une tâche de fond.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Par conséquent, ils ne seront pas disponibles immédiatement après l'activation mais apparaîtront après un certain temps.",
    "Send notifications for events" : "Envoyer une notification pour les évènements",
    "Notifications are sent via background jobs, so these must occur often enough." : "Les notifications sont envoyées par des tâches de fond qui doivent, par conséquent, être exécutées régulièrement.",
    "Send reminder notifications to calendar sharees as well" : "Envoyez également des notifications de rappel aux personnes partageant le calendrier",
    "Reminders are always sent to organizers and attendees." : "Des rappels sont toujours envoyés aux organisateurs et aux participants.",
    "Enable notifications for events via push" : "Activer les notifications push pour les évènements",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer aussi {calendarappstoreopen}l'application Calendrier{linkclose}, ou {calendardocopen}connecter à votre PC & téléphone pour synchroniser ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Merci de vérifier d'avoir correctement configuré {emailopen}le serveur de messagerie{linkclose}.",
    "There was an error updating your attendance status." : "Une erreur s'est produite lors de la mise à jour de votre statut de présence.",
    "Please contact the organizer directly." : "Merci de contacter l'organisateur directement.",
    "Are you accepting the invitation?" : "Acceptez-vous l'invitation ?",
    "Tentative" : "Provisoire",
    "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès.",
    "Todos" : "Tâches",
    "{actor} created todo {todo} in list {calendar}" : "{actor} a créé la tâche {todo} dans la liste {calendar}",
    "You created todo {todo} in list {calendar}" : "Vous avez créé la tâche {todo} dans la liste {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} a supprimé la tâche {todo} de la liste {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Vous avez supprimé la tâche {todo} de la liste {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} a mis à jour la tâche {todo} dans la liste {calendar}",
    "You updated todo {todo} in list {calendar}" : "Vous avez mis à jour la tâche {todo} dans la liste {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} a terminé la tâche {todo} de la liste {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vous avez terminé la tâche {todo} de la liste {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} a réouvert la tâche {todo} dans la liste {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Vous avez réouvert la tâche {todo} dans la liste {calendar}",
    "A calendar <strong>todo</strong> was modified" : "Une <strong>liste de tâches</strong> de l'agenda a été modifiée",
    "Invitation canceled" : "Invitation annulée",
    "Invitation updated" : "Invitation mise à jour",
    "Invitation" : "Invitation"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
